@@ -736,16 +736,15 @@ class Plinux:
             raise err
 
     def get_port_listeners_process_id(self, port: int) -> Union[int, list[int]]:
-        """Get processes ids of port listeners
+        r"""Get processes ids of port listeners
 
         sudo -S -p '' -- sh -c 'ss -ltpn | grep ":44301\s" | grep -Po "(?<=pid=)(\d*)" | uniq '
 
         :param port: /mnt/ssd-cache/
-        :param sudo:
         :return: Size in bytes
         """
 
-        cmd = f'ss -ltpn | grep ":{port}\s" | grep -Po "(?<=pid=)(\d*)" | uniq'
+        cmd = fr'ss -ltpn | grep ":{port}\s" | grep -Po "(?<=pid=)(\d*)" | uniq'
         result = self.run_cmd(cmd, sudo=True).stdout
         try:
             return int(result)
@@ -783,6 +782,17 @@ class Plinux:
         self.logger.info(f'Available: {self.is_host_available()}')
 
     # ---------- User management ----------
+    def get_user_id(self, user: str = None) -> int:
+        """Get Linux OS user ID
+
+        :param user:
+        :return: integer
+        """
+
+        user = self.username if user is None else user
+        result = self.run_cmd(f'id -u {user}')
+        return int(result.stdout)
+
     def kill_user_session(self, name: str):
         """
         Kill all user's ssh session and processes
@@ -793,17 +803,18 @@ class Plinux:
 
         return self.run_cmd(f'pkill -9 -u {name}', sudo=True)
 
-    def sqlite3(self, db: str, sql: str, sudo: bool = False, params: str = ''):
+    def sqlite3(self, db: str, sql: str, sudo: bool = False, params: str = '', timeout: int = 1000):
         """Simple work with the SQLite. Can use ".json" in response.
 
         :param db: DB path
         :param sql: SQL request
         :param params: i.e. "-line -header", "-csv"
         :param sudo:
+        :param timeout: ms. 1000 by default
         :return:
         """
 
-        cmd = f'sqlite3 {db} "{sql}" {params}'
+        cmd = f'sqlite3 -cmd ".timeout {timeout}" {db} "{sql}" {params}'
         return self.run_cmd(cmd, sudo=sudo)
 
     # OpenSSL
@@ -885,11 +896,3 @@ class Plinux:
     count = count_files
     stat = get_file_permissions
     md5 = get_md5
-
-
-class PackageNotFoundError(BaseException):
-    def __init__(self, package: str = None):
-        self.package = package or 'name is not specified by user'
-
-    def __str__(self):
-        return f'Package ({self.package}) not found!'
